@@ -12,15 +12,21 @@ from pyfiglet import Figlet
 import pyfiglet
 
 log = None
-def print_title(title, logger_name):
+def init_pycli(title, logger_name, log_file_name):
     os.system('cls' if os.name == 'nt' else 'clear')
     global log
     title = pyfiglet.figlet_format(title, font='slant')
     print(f'[blue]{title}[/blue]')
     FORMAT = "%(message)s"
-    logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", handlers=[RichHandler(rich_tracebacks=True, markup=True)], filname=logger_name)
+    #logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", handlers=[RichHandler(rich_tracebacks=True, markup=True)], filename=logger_name)
+    logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", filename=logger_name)
     traceback.install()
+
     log = logging.getLogger(logger_name)
+    formatter = logging.Formatter("%(asctime)s :%(levelname)s : %(name)s :%(message)s")
+    file_handler = logging.FileHandler(log_file_name)
+    file_handler.setFormatter(formatter)
+    log.addHandler(file_handler)
 
 class pyclibase(object):
     def __init__(self, args, name):
